Module: kamailio
Branch: master
Commit: 23a1d06737fa6d2509b6f88574ad171aa32cf275
URL:
https://github.com/kamailio/kamailio/commit/23a1d06737fa6d2509b6f88574ad171…
Author: Daniel-Constantin Mierla <miconda(a)gmail.com>
Committer: Daniel-Constantin Mierla <miconda(a)gmail.com>
Date: 2023-12-28T10:21:01+01:00
dialog: rename function parameter to avoid shadowing of global variable
---
Modified: src/modules/dialog/dlg_profile.c
---
Diff:
https://github.com/kamailio/kamailio/commit/23a1d06737fa6d2509b6f88574ad171…
Patch:
https://github.com/kamailio/kamailio/commit/23a1d06737fa6d2509b6f88574ad171…
---
diff --git a/src/modules/dialog/dlg_profile.c b/src/modules/dialog/dlg_profile.c
index 5dd3b372d49..43aee6278e0 100644
--- a/src/modules/dialog/dlg_profile.c
+++ b/src/modules/dialog/dlg_profile.c
@@ -70,21 +70,21 @@ static sruid_t _dlg_profile_sruid;
/*!
* \brief Add profile definitions to the global list
* \see new_dlg_profile
* \param profiles profile name
* \param has_value set to 0 for a profile without value, otherwise it has a value
* \return 0 on success, -1 on failure
*/
-int add_profile_definitions(char *profiles, unsigned int has_value)
+int add_profile_definitions(char *profiledef, unsigned int has_value)
{
char *p;
char *d;
str name;
unsigned int i;
- if(profiles == NULL || strlen(profiles) == 0)
+ if(profiledef == NULL || strlen(profiledef) == 0)
return 0;
- p = profiles;
+ p = profiledef;
do {
/* locate name of profile */
name.s = p;
@@ -70,21 +70,21 @@ static sruid_t _dlg_profile_sruid;
* \brief Add profile definitions to the global list
* \see new_dlg_profile
- * \param profiles profile name
+ * \param profiledef profile name
* \param has_value set to 0 for a profile without value, otherwise it has a value
* \return 0 on success, -1 on failure